{% autoescape off %}
Hello,

Tu as perdu ton mot de passe, ou quelqu’un essayant maladroitement de se faire passer pour toi a essayé de nous le faire croire.

Si tu veux changer ton mot de passe, va simplement à cette adresse:
{% block reset_link %}
{{ protocol }}://{{ domain }}{% url 'password_reset_confirm' uidb64=uid token=token %}
{% endblock %}

PS: Au cas où tu aurais aussi oublié ton nom d’utilisateur, c’est {{ user.username }}

{% endautoescape %}
